@@ -216,7 +216,7 @@ class Database:
             link_str = link_url + index_str + '&' + freq_str + '&' + rolling_day_str + '&' + rolling_time_str + '&' + year_month_involved_list_str + '&' \
                        + token_str + '&' + database_str + '&' \
                        + start_date_str + '&' + end_date_str
-
+            
             response = requests.get(link_str)
             result_list = json.loads(json.loads(response.content).replace("'", "\""))
 
@@ -256,7 +256,7 @@ class Database:
                                 break
                         else:
                             back_cut_off_date = max(date_list)
-    
+                                        
                     if df.loc[0,'expiry_date'] == '20130530':
                         front_cut_off_date = 20130501
                     
@@ -409,8 +409,8 @@ class Database:
             json_content = json.loads(response.content)
             json_content = json_content.replace(' nan', '\" nan\"')
 
-            #result = ast.literal_eval(json_content)
-            result = json.loads(json.loads(response.content).replace("'", "\""))
+            result = ast.literal_eval(json_content)
+            #result = json.loads(json.loads(response.content).replace("'", "\""))
 
             df_list = []
             for item in result:
@@ -420,10 +420,12 @@ class Database:
                     df['date'] = str(date_int)
                     df_list.append(df)
             df = pd.concat(df_list)
-
+            
+            
             df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
             df = df.set_index(keys='date')
             df = df.sort_index()
+
             return df
         else:
             err_msg = 'Error in: '
